==> yieldable-streams-0.1.0.tgz: package/yieldable-streams.js <==
(function() {
  var autocreate, base_mixin, factory, readable_mixin, redefine, rs, thunks, writable_mixin,
    extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
    hasProp = {}.hasOwnProperty;

  rs = require('readable-stream');

  redefine = require('redefine');

  autocreate = require('autocreate');

  thunks = function() {
    return (thunks = require('thunks')()).apply(this, arguments);
  };

  base_mixin = {
    spi: redefine.later(function() {
      var me, spi;
      spi = {};
      me = this;
      ['read', 'write', 'end'].forEach(function(key) {
        var method;
        if (method = me["_spi_" + key]) {
          return spi[key] = function() {
            return method.apply(me, arguments);
          };
        }
      });
      return function() {
        return spi;
      };
    }),
    _spi_end: function(err) {
      if (err) {
        this.emit('error', err);
      }
      if (this._spi_write) {
        this.push(null);
      }
      if (this._spi_read) {
        this.end();
      }
    }
  };

  writable_mixin = {
    dbuf: redefine.later(Array),
    rreq: redefine.later(Array),
    __init__: function() {
      this.wreq = void 0;
      this.on('pipe', (function(_this) {
        return function(s) {
          return s.on('error', function(e) {
            return _this._tpush(null, null, e);
          });
        };
      })(this));
      return this.on('finish', (function(_this) {
        return function() {
          return _this._tpush(null, null, null);
        };
      })(this));
    },
    _write: function(data, enc, done) {
      return this._tpush(done, data);
    },
    _tpush: function(done, data, err) {
      var rr;
      if (rr = this.rreq.shift()) {
        rr(err != null ? err : null, data);
      } else {
        this.dbuf.push(err != null ? err : null, data);
      }
      if (done) {
        if (this.rreq.length) {
          done();
        } else {
          this.wreq = done;
        }
      }
    },
    _spi_read: function() {
      return (function(_this) {
        return function(done) {
          var d1, d2;
          if (_this._writableState.finished || _this.dbuf.length) {
            d1 = _this.dbuf.length ? _this.dbuf.shift() : null;
            d2 = _this.dbuf.length ? _this.dbuf.shift() : null;
            process.nextTick(function() {
              return done(d1, d2);
            });
          } else {
            _this.rreq.push(done);
          }
          if (_this.wreq) {
            process.nextTick(_this.wreq);
            _this.wreq = void 0;
          }
        };
      })(this);
    }
  };

  readable_mixin = {
    ww: redefine.later(Array),
    _read: function() {
      if (this.ww.length) {
        return this.ww.shift()();
      }
    },
    _spi_write: function(data) {
      if (this.push(data)) {
        return process.nextTick;
      } else {
        return (function(_this) {
          return function(done) {
            return _this.ww.push(done);
          };
        })(this);
      }
    }
  };

  factory = function(opts, fn) {
    if (typeof opts === "function") {
      fn = opts;
      opts = {
        objectMode: true
      };
    }
    return (function(_this) {
      return function() {
        var doEnd, gen, spi, stream;
        stream = new _this(opts);
        gen = fn.apply(spi = stream.spi(), arguments);
        doEnd = function(e) {
          return spi.end(e);
        };
        if (typeof (gen != null ? gen.then : void 0) === "function") {
          gen.then((function() {
            return spi.end();
          }), doEnd);
        } else if (typeof gen === "function") {
          gen(doEnd);
        } else if (typeof (gen != null ? gen.next : void 0) === "function") {
          thunks.call(spi, gen)(doEnd);
        }
        return stream;
      };
    })(this);
  };

  exports.Readable = (function(superClass) {
    var Readable;

    extend(Readable, superClass);

    Readable = autocreate(Readable);

    function Readable() {
      Readable.__super__.constructor.apply(this, arguments);
      if (typeof this.__init__ === "function") {
        this.__init__();
      }
    }

    Readable.factory = factory;

    redefine(Readable.prototype, base_mixin);

    redefine(Readable.prototype, readable_mixin);

    return Readable;

  })(rs.Readable);

  exports.Writable = (function(superClass) {
    var Writable;

    extend(Writable, superClass);

    Writable = autocreate(Writable);

    function Writable() {
      Writable.__super__.constructor.apply(this, arguments);
      if (typeof this.__init__ === "function") {
        this.__init__();
      }
    }

    Writable.factory = factory;

    redefine(Writable.prototype, base_mixin);

    redefine(Writable.prototype, writable_mixin);

    return Writable;

  })(rs.Writable);

  exports.Duplex = (function(superClass) {
    var Duplex;

    extend(Duplex, superClass);

    Duplex = autocreate(Duplex);

    function Duplex() {
      Duplex.__super__.constructor.apply(this, arguments);
      if (typeof this.__init__ === "function") {
        this.__init__();
      }
    }

    Duplex.factory = factory;

    redefine(Duplex.prototype, base_mixin);

    redefine(Duplex.prototype, readable_mixin);

    redefine(Duplex.prototype, writable_mixin);

    return Duplex;

  })(rs.Duplex);

}).call(this);

==> yieldable-streams-0.2.0.tgz: package/yieldable-streams.js <==
(function() {
  var autocreate, base_mixin, factory, readable_mixin, redefine, rs, thunks, transform_mixin, writable_mixin,
    extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
    hasProp = {}.hasOwnProperty;

  rs = require('readable-stream');

  redefine = require('redefine');

  autocreate = require('autocreate');

  thunks = function() {
    return (thunks = require('thunks')()).apply(this, arguments);
  };

  base_mixin = {
    spi: redefine.later(function() {
      var me, spi;
      spi = {};
      me = this;
      ['read', 'write', 'end'].forEach(function(key) {
        var method;
        if (method = me["_spi_" + key]) {
          return spi[key] = function() {
            return method.apply(me, arguments);
          };
        }
      });
      return function() {
        return spi;
      };
    }),
    _spi_end: function(err) {
      if (err) {
        this.emit('error', err);
      }
      if (this._spi_write) {
        this.push(null);
      }
      if (this._spi_read) {
        this.end();
      }
    }
  };

  writable_mixin = {
    dbuf: redefine.later(Array),
    rreq: redefine.later(Array),
    __init__: function() {
      this.wreq = void 0;
      this.on('pipe', (function(_this) {
        return function(s) {
          return s.on('error', function(e) {
            return _this._tpush(null, null, e);
          });
        };
      })(this));
      return this.once('prefinish', (function(_this) {
        return function() {
          return _this._tpush(null, null, null);
        };
      })(this));
    },
    _write: function(data, enc, done) {
      return this._tpush(done, data);
    },
    _tpush: function(done, data, err) {
      var rr;
      if (rr = this.rreq.shift()) {
        rr(err != null ? err : null, data);
      } else {
        this.dbuf.push(err != null ? err : null, data);
      }
      if (done) {
        if (this.rreq.length) {
          done();
        } else {
          this.wreq = done;
        }
      }
    },
    _spi_read: function() {
      return (function(_this) {
        return function(done) {
          var d1, d2;
          if (_this._writableState.finished || _this.dbuf.length) {
            d1 = _this.dbuf.length ? _this.dbuf.shift() : null;
            d2 = _this.dbuf.length ? _this.dbuf.shift() : null;
            process.nextTick(function() {
              return done(d1, d2);
            });
          } else {
            _this.rreq.push(done);
          }
          if (_this.wreq) {
            process.nextTick(_this.wreq);
            _this.wreq = void 0;
          }
        };
      })(this);
    }
  };

  readable_mixin = {
    ww: redefine.later(Array),
    _read: function() {
      if (this.ww.length) {
        return this.ww.shift()();
      }
    },
    _spi_write: function(data) {
      if (this.push(data)) {
        return process.nextTick;
      } else {
        return (function(_this) {
          return function(done) {
            return _this.ww.push(done);
          };
        })(this);
      }
    }
  };

  transform_mixin = {
    __init__: function() {
      this.wreq = void 0;
      return this.on('pipe', (function(_this) {
        return function(s) {
          return s.on('error', function(e) {
            return _this._tpush(null, null, e);
          });
        };
      })(this));
    },
    _read: function() {
      readable_mixin._read.call(this);
      return rs.Transform.prototype._read.apply(this, arguments);
    },
    _write: rs.Transform.prototype._write,
    _transform: writable_mixin._write,
    _flush: function(done) {
      return this._tpush(done, null, null);
    }
  };

  factory = function(opts, fn) {
    if (typeof opts === "function") {
      fn = opts;
      opts = {
        objectMode: true
      };
    }
    return (function(_this) {
      return function() {
        var doEnd, gen, spi, stream;
        stream = new _this(opts);
        gen = fn.apply(spi = stream.spi(), arguments);
        doEnd = function(e) {
          return spi.end(e);
        };
        if (typeof (gen != null ? gen.then : void 0) === "function") {
          gen.then((function() {
            return spi.end();
          }), doEnd);
        } else if (typeof gen === "function") {
          gen(doEnd);
        } else if (typeof (gen != null ? gen.next : void 0) === "function") {
          thunks.call(spi, gen)(doEnd);
        }
        return stream;
      };
    })(this);
  };

  exports.Readable = (function(superClass) {
    var Readable;

    extend(Readable, superClass);

    function Readable() {
      return Readable.__super__.constructor.apply(this, arguments);
    }

    Readable = autocreate(Readable);

    Readable.factory = factory;

    redefine(Readable.prototype, base_mixin);

    redefine(Readable.prototype, readable_mixin);

    return Readable;

  })(rs.Readable);

  exports.Writable = (function(superClass) {
    var Writable;

    extend(Writable, superClass);

    Writable = autocreate(Writable);

    function Writable() {
      Writable.__super__.constructor.apply(this, arguments);
      this.__init__();
    }

    Writable.factory = factory;

    redefine(Writable.prototype, base_mixin);

    redefine(Writable.prototype, writable_mixin);

    return Writable;

  })(rs.Writable);

  exports.Duplex = (function(superClass) {
    var Duplex;

    extend(Duplex, superClass);

    Duplex = autocreate(Duplex);

    function Duplex() {
      Duplex.__super__.constructor.apply(this, arguments);
      this.__init__();
    }

    Duplex.factory = factory;

    redefine(Duplex.prototype, base_mixin);

    redefine(Duplex.prototype, readable_mixin);

    redefine(Duplex.prototype, writable_mixin);

    return Duplex;

  })(rs.Duplex);

  exports.Transform = (function(superClass) {
    var Transform;

    extend(Transform, superClass);

    Transform = autocreate(Transform);

    function Transform() {
      Transform.__super__.constructor.apply(this, arguments);
      this.__init__();
    }

    Transform.factory = factory;

    redefine(Transform.prototype, base_mixin);

    redefine(Transform.prototype, readable_mixin, {
      configurable: true
    });

    redefine(Transform.prototype, writable_mixin, {
      configurable: true
    });

    redefine(Transform.prototype, transform_mixin);

    return Transform;

  })(rs.Transform);

}).call(this);
